aboutsummaryrefslogtreecommitdiffstats
path: root/src/output.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/output.h')
-rw-r--r--src/output.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/output.h b/src/output.h
index 8d59eec..a75ebfa 100644
--- a/src/output.h
+++ b/src/output.h
@@ -199,7 +199,7 @@ ssize_t add_filter(struct output* output, struct filter* filter);
/**
* Recalculate the resulting gamma and
* update push the new gamam ramps to the CRTC
*
* @param output The output
* @param first_updated The index of the first added or removed filter
@@ -207,3 +207,12 @@ ssize_t add_filter(struct output* output, struct filter* filter);
*/
int flush_filters(struct output* output, size_t first_updated);
+/**
+ * Make identity mapping ramps
+ *
+ * @param ramps Output parameter for the ramps
+ * @param output The output for which the ramps shall be configured
+ * @return Zero on success, -1 on error
+ */
+int make_plain_ramps(union gamma_ramps* ramps, struct output* output);
+
@@ -199,7 +199,7 @@ ssize_t add_filter(struct output* output, struct filter* filter);
/**
* Recalculate the resulting gamma and
- * update push the new gamam ramps to the CRTC
+ * update push the new gamma ramps to the CRTC
*
* @param output The output